@@ -134,7 +134,7 @@ void Session::setupSession(SessionType type)
     }
 }
 
-Terminal *Session::addTerminal(QWidget *parent, QString workingDir)
+Terminal *Session::addTerminal(QSplitter *parent, QString workingDir)
 {
     if (workingDir.isEmpty()) {
         // fallback to session's default working dir
@@ -159,6 +159,8 @@ Terminal *Session::addTerminal(QWidget *parent, QString workingDir)
     if (terminalWidget)
         terminalWidget->setFocus();
 
+    parent->addWidget(term->partWidget());
+
     return term;
 }
 
@@ -604,3 +606,5 @@ bool Session::wantsBlur() const
         return terminal->wantsBlur();
     });
 }
+
+#include "moc_session.cpp"
